==> nedi-1.0.7p0.tgz: nedi/html/languages/bern dt/gui.php <==
<?PHP
// Bernese Swiss German language file, Obelix & Remo Rickli
$charset	= "iso-8859-1";

//Verbs usually don't precede nouns
$verb1		= 0;

//Labels
$acslbl		= "Ahtbl";
$acklbl		= "Beschttig";
$addlbl		= "Derzutu";
$adrlbl		= "Adrss";
$alllbl		= "Aui";
$alrlbl		= "Scho";
$agelbl		= "Auter";
$altlbl		= "Auternativ";
$arclbl		= "Bog";
$avalbl		= "Hets no";
$avglbl		= "Mittu";
$buplbl		= "Sichr";
$bwdlbl		= "Schluuch";
$cfglbl		= "Konfiguration";
$chglbl		= "nderig";
$clalbl		= "Klass";
$cmblbl		= "Kombination";
$cmdlbl		= "Usfehr";
$cmplbl		= "Vergliich";
$cmtlbl		= "Kommentar";
$cnclbl		= "Verbindig";
$cndlbl		= "Bedienig";
$coplbl		= "Kopier";
$conlbl		= "Kontakt";
$cuslbl		= "Spezial";
$dellbl		= "Abfackl";
$deplbl		= "Abhngigkit";
$deslbl		= "Beschriib";
$dislbl		= "Ufteilig";
$dsclbl		= "Fing";
$duplbl		= "Doppleti";
$durlbl		= "Duur";
$collbl		= "Schpalt";
$dstlbl		= "Deschtination";
$edilbl		= "Editier";
$emplbl		= "Lr";
$endlbl		= "ndi";
$explbl		= "Exportier";
$faslbl		= "Schnu";
$errlbl		= "Fhler";
$fltlbl		= "Fiuter";
$faslbl		= "Diffig";
$fillbl		= "Datei";
$fislbl		= "Zerscht";
$frelbl		= "Frei";
$frmlbl		= "Format";
$fullbl		= "Vou";
$fwdlbl		= "Wiiterleite";
$gralbl		= "Heugeli";
$grdlbl		= "Grad";
$grplbl		= "Raglt";
$hislbl		= "Gschicht";
$imglbl		= "Hugeli";
$implbl		= "Importier";
$inblbl		= "Igehend";
$invlbl		= "Inventar";
$isolbl		= "Isoliert";
$laslbl		= "Zletscht";
$latlbl		= "Verzgerig";
$lenlbl		= "Lngi";
$levlbl		= "Stuf";
$limlbl		= "Limit";
$loclbl		= "Ort";
$lodlbl		= "Laschd";
$loslbl		= "Verlor";
$lstlbl		= "Lischt";
$manlbl		= "Houpt";
$maxlbl		= "Maximum";
$memlbl		= "Spycher";
$metlbl		= "Gfoggu";
$mdllbl		= "Modu";
$mgtlbl		= "Verwautig";
$msglbl		= "Ereignis";
$msklbl		= "Mask";
$mullbl		= "Mehreri";
$namlbl		= "Nam";
$netlbl		= "Netzwrch";
$neblbl		= "Nachbar";
$newlbl		= "Ni";
$nodlbl		= "Chnot";
$nomlbl		= "Zigner";
$nonlbl		= "Keni";
$numlbl		= "Mngi";
$optlbl		= "Optimiert";
$orilbl		= "Originau";
$oublbl		= "Usgehend";
$poplbl		= "Bevlkerig";
$prilbl		= "Prioritt";
$qutlbl		= "Liislig";
$rnglbl		= "Beriich";
$realbl		= "Ls";
$replbl		= "Flick";
$reslbl		= "Zrggsetze";
$rltlbl		= "chtzyt";
$rotlbl		= "Dri";
$seclbl		= "Sicherheit";
$sellbl		= "Uswau";
$serlbl		= "Seri#";
$shplbl		= "Gmoeg";
$sholbl		= "Zig";
$sizlbl		= "Grssi";
$slolbl		= "Schngge";
$sndlbl		= "Snde";
$spdlbl		= "Gschwindigkeit";
$srclbl		= "Quell";
$srtlbl		= "Sortier";
$srvlbl		= "Dienscht";
$stalbl		= "Schtatus";
$strlbl		= "Geradi";
$stslbl		= "Schtatistik";
$sttlbl		= "Schtart";
$sumlbl		= "bersicht";
$tgtlbl		= "Ziu";
$timlbl		= "Zyt";
$tmplbl		= "Tmpratur";
$totlbl		= "Totau";
$trflbl		= "Verchehr";
$typlbl		= "Tp";
$undlbl		= "Unentdeckt";
$updlbl		= "Aktualisiere";
$upllbl		= "Ufelade";
$usrlbl		= "Benutzer";
$vallbl		= "Wrt";
$venlbl		= "Hrsteuer";
$verlbl		= "Version";
$woulbl		= "Ohni";
$wrtlbl		= "Schriib";
$wtylbl		= "Garantii";

// Meldungen
$nokmsg		= "<h4>Du hesch hi nt verlor!</h4>\n";
$toumsg		= "<h4>Zytlimi erreicht oder keis Resultat!</h4>\n";
$lopmsg		= "gits bereits im Pfad (chnnt  Routing Loop si)!\n";
$cfmmsg         = "Sitt ihr sicher?";

// Zeit
$tim['n']	= "Jitz";
$tim['t']	= "Htt";
$tim['s']	= "Sekund";
$tim['i']	= "Minut";
$tim['h']	= "Stund";
$tim['d']	= "Tag";
$tim['w']	= "Wuch";
$tim['m']	= "Mont";
$tim['y']	= "Jahr";

// Places
$place['r']	= "Region";
$place['c']	= "Stadt";
$place['b']	= "Gebude";
$place['f']	= "Stock";
$place['o']	= "Ruum";
$place['a']	= "Rack";

// Groessen
$siz['t']	= "Munzig";
$siz['s']	= "Miggerig";
$siz['m']	= "Mittu";
$siz['l']	= "Risig";
$siz['x']	= "Jumbo";

// Meldungsklassen
$mlvl['10']	= "Angeri";
$mlvl['50']	= "Info";
$mlvl['100']	= "Ftzu";
$mlvl['150']	= "Warnig";
$mlvl['200']	= "Alarm";
$mlvl['250']	= "Notfau";

// Lagerzustand
$stco['10']	= "Ni";
$stco['100']	= "Aktiv";
$stco['150']	= "Gchaflet";
$stco['200']	= "Gschprngt";

// Incident Gruppen
$igrp['1']	= "Ni";
$igrp['10']	= "Infrastruktur";
$igrp['11']	= "Stromusfau";
$igrp['12']	= "Bouarbeit";
$igrp['13']	= "Naturgwaute";
$igrp['14']	= "Telefhndler";
$igrp['20']	= "Usrschtig";
$igrp['21']	= "Netzteil";
$igrp['22']	= "Schassi";
$igrp['23']	= "Ischueb";
$igrp['24']	= "Softwer";
$igrp['25']	= "Vercher";
$igrp['30']	= "Mnsch";
$igrp['31']	= "Wartig";
$igrp['32']	= "Konfigurierfhler";
$igrp['33']	= "Baschtler";
$igrp['34']	= "Hacker";

?>

==> nedi-1.0.8p11.tgz: nedi/html/languages/bern dt/gui.php <==
<?PHP
// Bernese Swiss German language file, Obelix & Remo Rickli
$charset	= "iso-8859-1";

//Verbs usually don't precede nouns
$verb1		= 0;

//Labels
$acklbl		= "Beschttig";
$acslbl		= "Ahtbl";
$actlbl		= "Aktion";
$addlbl		= "Derzutu";
$adrlbl		= "Adrss";
$alllbl		= "Aui";
$alrlbl		= "Scho";
$agelbl		= "Auter";
$altlbl		= "Auternativ";
$arclbl		= "Bog";
$avalbl		= "Hets no";
$avglbl		= "Mittu";
$buplbl		= "Sichr";
$bwdlbl		= "Schluuch";
$cfglbl		= "Konfiguration";
$chglbl		= "nderig";
$clalbl		= "Klass";
$cmblbl		= "Kombination";
$cmdlbl		= "Usfehr";
$cmplbl		= "Vergliich";
$cmtlbl		= "Kommentar";
$cnclbl		= "Verbindig";
$cndlbl		= "Bedienig";
$collbl		= "Schpalt";
$conlbl		= "Kontakt";
$coplbl		= "Kopier";
$cuslbl		= "Spezial";
$dcalbl		= "Wgwrf";
$dellbl		= "Abfackl";
$deplbl		= "Abhngigkit";
$deslbl		= "Beschriib";
$dislbl		= "Ufteilig";
$dsalbl		= "Diseiblt";
$dsclbl		= "Fing";
$duplbl		= "Doppleti";
$durlbl		= "Duur";
$drplbl		= "Chbl";
$dstlbl		= "Deschtination";
$edilbl		= "Editier";
$emplbl		= "Lr";
$endlbl		= "ndi";
$errlbl		= "Fhler";
$explbl		= "Exportier";
$faslbl		= "Diffig";
$fltlbl		= "Fiuter";
$fillbl		= "Datei";
$fislbl		= "Zerscht";
$frelbl		= "Frei";
$frmlbl		= "Format";
$fullbl		= "Vou";
$fwdlbl		= "Wiiterleite";
$gralbl		= "Heugeli";
$grdlbl		= "Grad";
$grplbl		= "Raglt";
$hislbl		= "Gschicht";
$icelbl		= "Rchnig";
$imglbl		= "Hugeli";
$implbl		= "Importier";
$inblbl		= "Igehend";
$inclbl		= "Reblt";
$idxlbl		= "Index";
$inflbl		= "Info";
$invlbl		= "Inventar";
$isolbl		= "Isoliert";
$laslbl		= "Zletscht";
$latlbl		= "Verzgerig";
$lenlbl		= "Lngi";
$levlbl		= "Stuf";
$limlbl		= "Limit";
$loclbl		= "Ort";
$lodlbl		= "Laschd";
$loglbl		= "Protokou";
$loslbl		= "Verlor";
$lstlbl		= "Lischt";
$manlbl		= "Houpt";
$maxlbl		= "Maximum";
$memlbl		= "Spycher";
$metlbl		= "Gfoggu";
$mdllbl		= "Modu";
$mgtlbl		= "Verwautig";
$modlbl		= "Modus";
$monlbl		= "brwach";
$msglbl		= "Ereignis";
$msklbl		= "Mask";
$mullbl		= "Mehreri";
$namlbl		= "Nam";
$netlbl		= "Netzwrch";
$neblbl		= "Nachbar";
$newlbl		= "Ni";
$nodlbl		= "Chnot";
$notlbl		= "Nid";
$nomlbl		= "Zigner";
$nonlbl		= "Keni";
$numlbl		= "Mngi";
$opolbl		= "Option";
$optlbl		= "Optimiert";
$orilbl		= "Originau";
$oublbl		= "Usgehend";
$paslbl		= "Passwort";
$poplbl		= "Bevukerig";
$porlbl		= "Port";
$prolbl		= "Protokou";
$prilbl		= "Prioritt";
$qutlbl		= "Liislig";
$rcvlbl		= "Empfang";
$realbl		= "Ls";
$replbl		= "Flick";
$reslbl		= "Zrggsetze";
$rltlbl		= "chtzyt";
$rnglbl		= "Beriich";
$rotlbl		= "Dri";
$rpllbl		= "Ersetz";
$rptlbl		= "Widerhol";
$seclbl		= "Sicherheit";
$sellbl		= "Uswau";
$serlbl		= "Seri#";
$shplbl		= "Gmoeg";
$sholbl		= "Zig";
$sizlbl		= "Grssi";
$slolbl		= "Schngge";
$sndlbl		= "Snde";
$spdlbl		= "Gschwindigkeit";
$srclbl		= "Quell";
$srtlbl		= "Sortier";
$srvlbl		= "Dienscht";
$stalbl		= "Schtatus";
$strlbl		= "Geradi";
$stslbl		= "Schtatistik";
$sttlbl		= "Schtart";
$sumlbl		= "bersicht";
$tgtlbl		= "Ziu";
$timlbl		= "Zyt";
$titlbl		= "Titu";
$tmplbl		= "Tmpratur";
$toplbl		= "Top";
$totlbl		= "Totau";
$trflbl		= "Verchehr";
$tstlbl		= "Tescht";
$typlbl		= "Tp";
$undlbl		= "Unentdeckt";
$updlbl		= "Aktualisiere";
$upllbl		= "Ufelade";
$uptlbl		= "Loufzyt";
$usrlbl		= "Benutzer";
$vallbl		= "Wrt";
$venlbl		= "Hrsteuer";
$verlbl		= "Version";
$woulbl		= "Ohni";
$wrtlbl		= "Schriib";
$wtylbl		= "Garantii";

// Meldungen
$cfmmsg         = "sitt ihr sicher?";
$delmsg		= "wrde glscht";
$lopmsg		= "gits bereits im Pfad (chnnt  Routing Loop si)!\n";
$nokmsg		= "<h4>Du hesch hi nt verlor!</h4>\n";
$toumsg		= "<h4>Zytlimi erreicht oder keis Resultat!</h4>\n";

// Zeit
$tim['n']	= "Jitz";
$tim['t']	= "Htt";
$tim['s']	= "Sekund";
$tim['i']	= "Minut";
$tim['h']	= "Stund";
$tim['d']	= "Tag";
$tim['w']	= "Wuch";
$tim['m']	= "Mont";
$tim['y']	= "Jahr";

// Places
$place['r']	= "Region";
$place['c']	= "Stadt";
$place['b']	= "Gebude";
$place['f']	= "Stock";
$place['o']	= "Ruum";
$place['a']	= "Rack";

// Groessen
$siz['t']	= "Munzig";
$siz['s']	= "Miggerig";
$siz['m']	= "Mittu";
$siz['l']	= "Risig";
$siz['x']	= "Jumbo";

// Meldungsklassen
$mlvl['10']	= "Angeri";
$mlvl['50']	= "Info";
$mlvl['100']	= "Ftzu";
$mlvl['150']	= "Warnig";
$mlvl['200']	= "Alarm";
$mlvl['250']	= "Notfau";

// Lagerzustand
$stco['10']	= "Ni";
$stco['100']	= "Aktiv";
$stco['150']	= "Gchaflet";
$stco['200']	= "Gschprngt";
$stco['250'] 	= "Unbekannt";

// Incident Gruppen
$igrp['1']	= "Ni";
$igrp['10']	= "Infrastruktur";
$igrp['11']	= "Stromusfau";
$igrp['12']	= "Bouarbeit";
$igrp['13']	= "Naturgwaute";
$igrp['14']	= "Telefhndler";
$igrp['15']	= "Viecher";
$igrp['20']	= "Usrschtig";
$igrp['21']	= "Netzteil";
$igrp['22']	= "Schassi";
$igrp['23']	= "Ischueb";
$igrp['24']	= "Softwer";
$igrp['25']	= "Vercher";
$igrp['30']	= "Mnsch";
$igrp['31']	= "Wartig";
$igrp['32']	= "Konfigurierfhler";
$igrp['33']	= "Baschtler";
$igrp['34']	= "Hacker";

?>
